pub fn deserialize<'de, D>(deserializer: D) -> Result<Vec<Addr>, D::Error>where D: Deserializer<'de>,
Deserializes an array of protocol://host:port URLs into Addrs.
protocol://host:port
Addr
Returns an error if an element is not a valid address or if the underlying deserializer fails.